@@ -6,7 +6,7 @@ Mojo::IRC - IRC Client for the Mojo IOLoop
 
 =head1 VERSION
 
-0.26
+0.27
 
 =head1 SYNOPSIS
 
@@ -115,9 +115,8 @@ use Unicode::UTF8;
 use constant DEBUG => $ENV{MOJO_IRC_DEBUG} ? 1 : 0;
 use constant DEFAULT_CERT => $ENV{MOJO_IRC_CERT_FILE} || catfile dirname(__FILE__), 'mojo-irc-client.crt';
 use constant DEFAULT_KEY  => $ENV{MOJO_IRC_KEY_FILE}  || catfile dirname(__FILE__), 'mojo-irc-client.key';
-use constant OFFLINE => $ENV{MOJO_IRC_OFFLINE} ? 1 : 0;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 my %CTCP_QUOTE = ("\012" => 'n', "\015" => 'r', "\0" => '0', "\cP" => "\cP");
 
@@ -228,7 +227,7 @@ sub connect {
   my @tls;
 
   if ($self->{stream_id}) {
-    $self->$cb('');
+    Mojo::IOLoop->next_tick(sub { $self->$cb('') });
     return $self;
   }
 
@@ -244,15 +243,6 @@ sub connect {
   $self->{debug_key} ||= "$host:$port";
   $self->register_default_event_handlers;
 
-  if (OFFLINE) {
-    warn "MOJO_IRC_OFFLINE is deprecated! Use Test::Mojo::IRC instead";
-    $self->write(PASS => $self->pass, sub { }) if length $self->pass;
-    $self->write(NICK => $self->nick, sub { });
-    $self->write(USER => $self->user, 8, '*', ':' . $self->name, sub { });
-    $self->$cb('');
-    return $self;
-  }
-
   Scalar::Util::weaken($self);
   $self->{stream_id} = $self->ioloop->client(
     address => $host,
@@ -351,8 +341,8 @@ sub disconnect {
       }
     );
   }
-  else {
-    $self->$cb if $cb;
+  elsif ($cb) {
+    Mojo::IOLoop->next_tick(sub { $self->$cb });
   }
 
   $self;
@@ -395,17 +385,12 @@ sub write {
   my $buf  = Unicode::UTF8::encode_utf8(join(' ', @_), sub { $_[0] });
 
   Scalar::Util::weaken($self);
-  if (OFFLINE) {
-    warn "MOJO_IRC_OFFLINE is deprecated! Use Test::Mojo::IRC instead";
-    $self->{to_irc_server} .= "$buf\r\n";
-    $self->$cb('');
-  }
-  elsif (ref $self->{stream}) {
+  if (ref $self->{stream}) {
     warn "[$self->{debug_key}] <<< $buf\n" if DEBUG;
     $self->{stream}->write("$buf\r\n", sub { $self->$cb(''); });
   }
   else {
-    $self->$cb('Not connected');
+    Mojo::IOLoop->next_tick(sub { $self->$cb('Not connected.') });
   }
 
   $self;
@@ -582,14 +567,6 @@ CHUNK:
   }
 }
 
-if (OFFLINE) {
-  warn "MOJO_IRC_OFFLINE is deprecated! Use Test::Mojo::IRC instead";
-  *from_irc_server = sub {
-    warn "MOJO_IRC_OFFLINE is deprecated! Use Test::Mojo::IRC instead";
-    goto &_read;
-    }
-}
-
 =head1 COPYRIGHT
 
 This program is free software, you can redistribute it and/or modify it under
